Index: base/task_scheduler/delayed_task_manager.h |
diff --git a/base/task_scheduler/delayed_task_manager.h b/base/task_scheduler/delayed_task_manager.h |
index f5690cd67c17d0dadb44237a26a4e15890bc8659..840747bf94138b07f6193311aeec146200ce184a 100644 |
--- a/base/task_scheduler/delayed_task_manager.h |
+++ b/base/task_scheduler/delayed_task_manager.h |
@@ -23,7 +23,7 @@ |
namespace base { |
namespace internal { |
-class SchedulerThreadPool; |
+class SchedulerWorkerPool; |
class SchedulerWorkerThread; |
// A DelayedTaskManager holds delayed Tasks until they become ripe for |
@@ -36,18 +36,18 @@ class BASE_EXPORT DelayedTaskManager { |
~DelayedTaskManager(); |
// Adds |task| to a queue of delayed tasks. The task will be posted to |
// |thread_pool| with |sequence| and |worker_thread| the first time that |
// PostReadyTasks() is called while Now() is passed |task->delayed_run_time|. |
// |worker_thread| is a SchedulerWorkerThread owned by |thread_pool| or |
// nullptr. |
// |
// TODO(robliao): Find a concrete way to manage the memory of |worker_thread| |
// and |thread_pool|. These objects are never deleted in production, but it is |
// better not to spread this assumption throughout the scheduler. |
void AddDelayedTask(std::unique_ptr<Task> task, |
scoped_refptr<Sequence> sequence, |
SchedulerWorkerThread* worker_thread, |
- SchedulerThreadPool* thread_pool); |
+ SchedulerWorkerPool* worker_pool); |
// Posts delayed tasks that are ripe for execution. |
void PostReadyTasks(); |
@@ -36,18 +36,18 @@ class BASE_EXPORT DelayedTaskManager { |
~DelayedTaskManager(); |
// Adds |task| to a queue of delayed tasks. The task will be posted to |
- // |thread_pool| with |sequence| and |worker_thread| the first time that |
+ // |worker_pool| with |sequence| and |worker_thread| the first time that |
// PostReadyTasks() is called while Now() is passed |task->delayed_run_time|. |
@@ -36,18 +36,18 @@ class BASE_EXPORT DelayedTaskManager { |
// PostReadyTasks() is called while Now() is passed |task->delayed_run_time|. |
- // |worker_thread| is a SchedulerWorkerThread owned by |thread_pool| or |
+ // |worker_thread| is a SchedulerWorkerThread owned by |worker_pool| or |
// nullptr. |
// |
@@ -36,18 +36,18 @@ class BASE_EXPORT DelayedTaskManager { |
// |
// TODO(robliao): Find a concrete way to manage the memory of |worker_thread| |
- // and |thread_pool|. These objects are never deleted in production, but it is |
+ // and |worker_pool|. These objects are never deleted in production, but it is |
// better not to spread this assumption throughout the scheduler. |
void AddDelayedTask(std::unique_ptr<Task> task, |